Breakpoint

Struct Breakpoint 

pub struct Breakpoint {
    pub original_byte: u8,
    pub handlers: Vec<HookHandler>,
    pub module_name: String,
    pub export_name: String,
}
A breakpoint object Contains information about the hooked function, and the hooking function

Fields

original_byte: u8

Original byte of the breakpoint. Used to restore the process after removal of the breakpoint

handlers: Vec<HookHandler>

Hook handler functions. When the breakpoint is called, these are executed in registration order

module_name: String

Hooked function module name

export_name: String

Hooked function export name

Implementations

Source

impl Breakpoint

pub fn new( original_byte: u8, handler: HookHandler, module: String, export: String, ) -> Self

Creates a new breakpoint

pub fn push_handler(&mut self, handler: HookHandler)

Adds a handler to an existing breakpoint