Module engine

Module engine 

Contains the hook engine definition and logic. This is essentially the main logic of this crate

Structs

HookEngine
The core hooking engine Responsible for dispatching, registering, and removing hooks from the target process

Enums

DispatchResult
Result of the hooking operation