cradle-hooks
Contains the hooking logic in use by the cradle workspace (tools and plugins)
Re-exports
pub use defs::HookAction;pub use defs::HookContext;pub use defs::HookHandler;pub use defs::HookResult;pub use engine::DispatchResult;pub use engine::HookEngine;
Modules
- breakpoints
- Breakpoint definitions
- defs
- Definitions for the hooks, including utility functions
- engine
- Contains the hook engine definition and logic. This is essentially the main logic of this crate